from logging import getLogger
from os import environ
from typing import Optional, Any, Dict

import dotenv
import magic
from linebot import LineBotApi
from linebot.models import RichMenu, RichMenuSize

from .helper import validate_rich_menu_object
from .const import ACCESS_TOKEN_KEY, NO_TOKEN_TEXT


class LineRichMenu:
    def __init__(self, token: Optional[str] = None):
        self.token = token or environ.get(ACCESS_TOKEN_KEY)
        if self.token is None:
            self.logger.warning(NO_TOKEN_TEXT)
            exit(1)
        self.client = LineBotApi(self.token)

    @property
    def logger(self):
        return getLogger(self.__class__.__name__)

    def create_menu(
        self, data: Dict[str, Any], image_path: str, set_default: bool = False
    ):
        """

        :param set_default:
        :param data:
        :param image_path:
        :return:
        """
        mime = magic.from_file(image_path, mime=True)
        valid = validate_rich_menu_object(token=self.token, obj=data)

        if not valid:
            self.logger.error(
                "Invalid menu object, see https://developers.line.biz/en/reference/messaging-api/#rich-menu-object"
            )
            exit(1)

        if mime not in ["image/jpeg", "image/png"]:
            self.logger.error(
                "Invalid image file type, only PNG and JPG are supported. "
                "See https://developers.line.biz/en/reference/messaging-api/#upload-rich-menu-image"
            )
            exit(1)

        m = RichMenu(
            size=RichMenuSize(
                width=data["size"]["width"], height=data["size"]["height"]
            ),
            selected=set_default,  # override from data
            name=data["name"],
            chat_bar_text=data["chatBarText"],
            areas=data["areas"],
        )
        menu_id = self.client.create_rich_menu(rich_menu=m)

        with open(image_path, "rb") as img_file:
            self.client.set_rich_menu_image(
                rich_menu_id=menu_id, content_type=mime, content=img_file
            )

        if set_default:
            self.client.set_default_rich_menu(menu_id)

        return menu_id



import logging
from json import load
from os import environ
from typing import Optional

import click
from click import Context

from ..const import ACCESS_TOKEN_KEY, NO_TOKEN_TEXT
from ..menu import LineRichMenu

logger = logging.getLogger("LineRichMenu")


@click.group(context_settings={"show_default": True})
@click.option(
    "-t",
    "--token",
    required=False,
    type=str,
    envvar=ACCESS_TOKEN_KEY,
    help=f"Channel access token, can be set via {ACCESS_TOKEN_KEY} environment variable",
    default=lambda: environ.get(ACCESS_TOKEN_KEY, ""),
)
@click.pass_context
def main_cli(ctx: Context, token: Optional[str]):
    if token is None:
        logger.error(NO_TOKEN_TEXT)
        exit(1)
    ctx.ensure_object(dict)
    ctx.obj[ACCESS_TOKEN_KEY] = token


@main_cli.command()
@click.option(
    "-d",
    "--data",
    type=click.Path(exists=True),
    help="Rich menu object in json format, see https://developers.line.biz/en/reference/messaging-api/#rich-menu-object",
)  # noqa
@click.option("-i", "--image", type=click.Path(exists=True))
@click.option("--default", type=bool, default=False, help="Set menu as default")
@click.option(
    "-t",
    "--token",
    required=False,
    type=str,
    envvar=ACCESS_TOKEN_KEY,
    help=f"Channel access token, can be set via {ACCESS_TOKEN_KEY} environment variable",
    default=lambda: environ.get(ACCESS_TOKEN_KEY, ""),
)
@click.pass_context
def create(ctx: Context, data: str, image: str, default: bool):
    token = ctx.obj.get(ACCESS_TOKEN_KEY)
    with open(data, "r") as f:
        data_dict = load(f)
    tool = LineRichMenu(token=token)
    menu_id = tool.create_menu(data=data_dict, image_path=image, set_default=default)
    click.echo(menu_id)


if __name__ == "__main__":
    main_cli(obj={})



from typing import Any, Dict

import requests


def validate_rich_menu_object(token: str, obj: Dict[str, Any]) -> bool:
    resp = requests.post(
        "https://api.line.me/v2/bot/richmenu/validate",
        json=obj,
        headers={"Authorization": f"Bearer {token}"},
    )
    return resp.status_code == 200



# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': 'src'}

packages = \
['line_rich_menu', 'line_rich_menu.cli']

package_data = \
{'': ['*']}

install_requires = \
['click>=8.1.3,<9.0.0',
 'line-bot-sdk>=2.2.1,<3.0.0',
 'python-dotenv>=0.20.0,<0.21.0',
 'python-magic>=0.4.25,<0.5.0']

entry_points = \
{'console_scripts': ['line_rich_menu = line_rich_menu.cli.main:main_cli']}

setup_kwargs = {
    'name': 'line-rich-menu',
    'version': '0.0.1',
    'description': 'Rich Menu CLI for Line Bot',
    'long_description': None,
    'author': 'Nuttapat Koonarangsri',
    'author_email': 'webmaster@hackinteach.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
